# USER SETTINGS FOR BI ALERT PROTECT TOOL
#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'BI_alert_protect.ps1'
#   2. This script must be located in the same folder as script 'BI_alert_protect.ps1'
#   3. This script is suitable for 'BI_alert_protect.ps1' versions V3+
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# [REQUIRED] ENTER BLUE IRIS ALERTS FOLDER PATH
	# ... (string) like "D:\BlueIris\Alerts"
	# ... KEY POINT: If using a network share for Blue Iris storage, note that the BI service may
	#     not understand your file system designations like 'H:' etc. as these are user-specific. 
	#     Per the BI Help PDF, you should always use UNC names where possible (\\server\share).
	$bi_alerts_folder_path = 'YOUR_BLUE_IRIS_ALERTS_FOLDER_PATH'

	# [REQUIRED] ENTER BLUE IRIS NEW FOLDER PATH(S)
	# ... (list) comma-delimited, like 'D:\BlueIris\New','E:\BlueIris\New'
	# ... Use multiple values if your Blue Iris system is configured to use multiple 'New' folders
	# ... At least one value is required
	# ... KEY POINT: If using a network share for Blue Iris storage, note that the BI service may
	#     not understand your file system designations like 'H:' etc. as these are user-specific. 
	#     Per the BI Help PDF, you should always use UNC names where possible (\\server\share).
	$bi_new_folder_paths = 'YOUR_BLUE_IRIS_NEW_FOLDER_PATH(S)'
	#$bi_new_folder_paths = 'D:\BlueIris\New'
	#$bi_new_folder_paths = 'D:\BlueIris\New','J:\BlueIris\New'

	# [REQUIRED] ENTER BLUE IRIS DATABASE FOLDER PATH
	# ... (string) like 'C:\BlueIris\db'
	$bi_db_path = 'YOUR_BLUE_IRIS_DATABASE_FOLDER_PATH'

	# [REQUIRED] ENTER DESTINATION PATH THE SCRIPT'S OUTPUT
	# ... (string) like "D:\BI_alert_protect"
	# ... Note: Script will terminate with an ERR if $app_path is not defined
	$app_path = 'YOUR_SCRIPT_WORKING_FOLDER_PATH'

	# BLUE IRIS WEBSERVER

		# [REQUIRED] ENTER YOUR WEBSERVER'S ADDRESS & PORT
		# ... [string] like '192.168.1.3:81'
		$bi_webserver = "YOUR_BI_SERVER_ADDRESS:PORT"

		# [REQUIRED] ENTER YOUR WEBSERVER'S USERNAME & PASSWORD CREDENTIALS
		# ... CREDENTIALS ARE REQUIRED TO ACCESS THE BLUE IRIS WEBSERVER VIA THE JSON INTERFACE
		# ... NOTE: ACCOUNT MUST BE ADMIN if posting to the Blue Iris logfile
		# ... NOTE: to use credentials, be sure to uncheck 'Use secure session keys and login page' 
		#     in Blue Iris settings: click Settings > Web server > Advanced
		# ... [string] 
		$bi_user_name = "YOUR_BI_USER_NAME"
		$bi_user_pw = "YOUR_BI_USER_PASSORD"

# OPTIONAL SETTINGS

	# CUSTOM MEMO TAG
	
		# By default, a small 'tag' (^) is prepended the Alert's memo text when the script has modified the Alert. 
		# You can use this tag to quickly identify/find Alerts that have been 'repaired' by the script.

		# OPT-OUT OF ADDING A CUSTOM TAG TO THE ALERT'S MEMO
		# ... By default, a tag is prepended the Alert's memo text
		# ... Expecting $true or $false (default = $true)
		$apply_custom_memo_mark = $true
		#$apply_custom_memo_mark = $false

		# ENTER CUSTOM MEMO TAG STRING
		# ... By default, a caret (^) character is prepended the Alert's memo text
		# ... PLEASE NOTE: if you change the tag, keep in mind that Alert memos are limited to a length of 31 characters
		# ... [string] custom tag string
		$custom_memo_mark = '^'
		#$custom_memo_mark = 'AP;'

	# DUMMY/REPLACEMENT JPGS

		# ENTER CUSTOM IMAGE NUMBER WHEN REPLACEMENT JPGS EXTRACTED FROM BVR FILE
		# ... When a missing JPG is extracted from a BVR, the script can extract up to 10 JPGs over duration of alert
		# ... By default, the script uses the first of these images, however you may specify the use of a later image
		# ... [integer] 1 to 10; Default is 1
		$bvr_jpg_image_no = 1
		#$bvr_jpg_image_no = 3

		# ENTER CUSTOM HEIGHT OF REPLACEMENT JPGS EXTRACTED FROM BVR FILE
		# ... [integer] units are pix
		# ... Default is 0 (uses default stream height from Blue Iris HTTP interface command '/file/clips/')
		$bvr_jpg_height = 0
		#$bvr_jpg_height = 640

		# OPT-OUT OF ADDING OVERLAY TO REPLACEMENT/DUMMY JPGS
		# ... 2 lines like 'Replacement|Dummy JPG' & '(via BI_alert_protect)'
		# ... Expecting $true or $false (default = $true)
		$add_jpg_overlay = $true
		#$add_jpg_overlay = $false

		# ENTER DEFAULT LOCATION FOR MESSAGE OVERLAY ON REPLACEMENT JPGS
		# ... [STRING] options: ['TopLeft','TopMiddle','TopRight','BottomLeft','BottomMiddle','BottomRight','Center']
		# ... Default is 'Center'
		$jpg_overlay_location = 'Center'
		#$jpg_overlay_location = 'TopLeft'
		#$jpg_overlay_location = 'BottomMiddle'

		# ENTER DEFAULT FONT FOR MESSAGE OVERLAY ON REPLACEMENT JPGS
		# ... [STRING] Default is 'Courier New'
		$jpg_overlay_font = 'Courier New'
		#$jpg_overlay_font = 'Verdana'

	# FIX ZERO-DATE ALERTS
	
		# By default, when using argument -FixZeroDates, when the script finds an Alert
		# with a 'zero-date' in the Alert's database record, it will attempt to fix
		# database record by using the file creation date of the Alert's DAT or JPG file 
		# (in that order of preference). If neither file exists, then the script leaves 
		# the Alert's database record as is. You can opt-in to permanently delete the record 
		# from the Blue Iris database.
		
		# OPT-IN TO DELETING 'ZERO DATE' ALERTS LACKING BOTH A JPG AND DAT FILE
		# ... Expecting $true or $false (default = $false)
		$delete_unfixable_zerodate_alerts = $false
		#$delete_unfixable_zerodate_alerts = $true

	# BLUE IRIS WEBSERVER

		# OPT-IN TO USING CREDENTIALS FOR HTTP INTERFACE COMMANDS
		# ... Expecting $true or $false (default = $false)
		# ... Currently used for these HTTP commands: '/admin?log', '/admin?db=rebuild'
		$use_bi_creds = $false
		#$use_bi_creds = $true

	# OUTPUT CSV FILE

		# AUTO-OPEN OUTPUT CSV FILE
		# ... Expecting $true or $false (default is $false)
		$auto_open_csv_file = $false
		#$auto_open_csv_file = $true

		# AUTO-OPEN OUTPUT CSV FILE IN DEFAULT WINDOWS APPLICATION
		# ... Expecting $true or $false (default is $false)
		# ... $false displays the output CSV file in the Powershell Out-GridView Cmdlet UI
		# ... Learn more: https://learn.microsoft.com/en-us/powershell/module/microsoft.powershell.utility/out-gridview?view=powershell-7.3
		$auto_open_csv_file_in_def_app = $false
		#$auto_open_csv_file_in_def_app = $true

		# AUTO-OPEN OUTPUT CSV FILE IF OUTPUT HAS MORE THAN N ROWS
		# ... Expecting integer (default is 0)
		# ... 0 (zero) will always displays the Powershell Out-GridView Cmdlet UI
		$auto_open_csv_file_min_rows = 0
		#$auto_open_csv_file_min_rows = 20

		# OPT-OUT OF TIME STAMPING THE 'OUTPUT.CSV' FILES
		# ... Expecting $true or $false (default is $true)
		# ... These files are located in folder '$app_path'
		$timestamp_output_csv_files_flg = $true
		#$timestamp_output_csv_files_flg = $false

		# ENTER MAX LIFETIME FOR ARCHIVED 'OUTPUT.CSV' FILES
		# ... Expecting integer (default is 365)
		# ... the 'output.csv' files archived by this script are located in folder '$app_path'
		# ... To prevent this folder from growing excessively large, this setting deletes CSV files after a given age
		# ... (aka a 'pruning operation' that searches for output*_20*.csv older than a retention time)
		# ... TIP: Use 0 to disable monitoring of the archive folder
		$archive_lifetime_days = 365
		#$archive_lifetime_days = 0

	# POSTING TO THE BLUE IRIS LOGFILE
	
		# This logging functionality is provided as a means to document automated actions.
		# FURTHERMORE, a setting is provided to limit logging to when 'bi_alert_protect.ps1' is executed from the background 
		# (e.g., via Task Scheduler or Blue Iris actions).
		
		# BTW, even if you've enabled logging by default (via user setting $post_to_BI_logfile_flg below), 
		# logging can still be disabled on-demand -- via the script's -NoBiLog argument.

		# OPT-IN TO POSTING CUSTOM MESSAGES TO THE BLUE IRIS LOG
		# ... expecting $true or $false (default = $false)
		# ... NOTE: if value is $true, setting $bi_user_name (above) MUST BE ADMIN
		# ... NOTE: script parameter -NoBiLog can be used to temporarily override this setting (if $true)
		$post_to_BI_logfile_flg = $false
		#$post_to_BI_logfile_flg = $true

			# The following settings apply only if setting $post_to_BI_logfile_flg = $true

			# OPT-IN TO POSTING TO THE BLUE IRIS LOG ONLY FROM BACKGROUND
			# ... expecting $true or $false (default = $false)
			# ... $true avoids logging to Blue Iris logfile when using script from Console
			$post_to_BI_logfile_in_background_only_flg = $false
			#$post_to_BI_logfile_in_background_only_flg = $true

	# SCRIPT OPTIONS

		# OPT-IN TO DISABLING CLIP MAINTENANCE WHILE RUNNING SCRIPT
		# ... Expecting $true or $false; default is $false
		# ... You may want to enable this setting if running the script from Blue Iris or Task Scheduler 
		#     AT THE SAME TIME AS Blue Iris setting 'Compact/repair DB at' (Settings > Storage tab)
		$disable_clip_maintenance = $false
		#$disable_clip_maintenance = $true

		# OPT-IN TO BACKGROUND MESSAGING
		# ... Expecting $true or $false; default is $false
		# ... Key Points: 
		#     1. Background messages are enabled only if script is running in the background
		#     2. This global setting may be overridden on-demand by argument '-Quiet'
		$enable_bg_messages = $false
		#$enable_bg_messages = $true

# END USER SETTINGS
# ================================================
